# =============================================================================
# begin of file *gui_MPAPP.py*
# =============================================================================
# with function from the publication Primpke, S., C. Lorenz, R. Rascher-Friesenhausen, and G. Gerdts. 2017. 'An automated approach for microplastics analysis using focal plane array (FPA) FTIR microscopy and image analysis', Anal. Methods, 9: 1499-511.
#sprimpke@awi.de (c) 2019


# module imports
# =============================================================================
import tkinter
from tkinter import filedialog

import os
from Script_MPAPP_rev import analyse

#from idlelib.ToolTip import ToolTip

# class defs
# =============================================================================

class MyApp(tkinter.Frame):
    
    def __init__(self, master):
        tkinter.Frame.__init__(self, master)
        self.grid()

        self.__file_name = 'Select Data File!'
        self.got_file_name = False
        self.file_name = tkinter.StringVar()
        self.file_name.set(self.__file_name)
        self.__dir_name = 'Select Results Dir!'
        self.got_dir_name = False
        self.dir_name = tkinter.StringVar()
        self.dir_name.set(self.__dir_name)
        self.__pixelsize = '11.03'
        self.setpixelsize = tkinter.StringVar()
        self.setpixelsize.set(self.__pixelsize)
        self.been_analysed = False
        self.createWidgets()
        
        return
        
    def createWidgets(self):
        self.file_btn = tkinter.Button(self, text="file name", width=15)
        self.file_btn["command"] = self.get_file_name
        self.result_btn = tkinter.Button(self, text="result dir", width=15)
        self.result_btn["command"] = self.get_dir_name
        self.start_btn = tkinter.Button(self, text="Analyse", width=25)
        self.start_btn["command"] = self.run
        self.exit_btn = tkinter.Button(self, text="exit", width=15)
        self.exit_btn["command"] = self.quit
        self.pixelsize_btn = tkinter.Button(self, text="Set Pixelsize", width=15)
        self.pixelsize_btn["command"] = self.settopixelsize
        
        #file_ttp = ToolTip(self.file_btn, "Select data file")
        #result_ttp = ToolTip(self.result_btn, "Select results directory")
        #start_ttp = ToolTip(self.start_btn, "Run analysis")
        #exit_ttp = ToolTip(self.exit_btn, "Exit application")
        
        self.file_ent = tkinter.Entry(self, fg='red',
                                      textvariable=self.file_name, 
                                      state="readonly", width=20)
        self.dir_ent = tkinter.Entry(self, fg='red',
                                     textvariable=self.dir_name, 
                                     state="readonly", width=20)                                     
        self.pixelsize_ent = tkinter.Entry(self, fg='black',
                                     textvariable=self.setpixelsize, 
                                     width=20)
        
        self.file_btn.grid(row=0, column=0)
        self.result_btn.grid(row=1, column=0)
        self.pixelsize_btn.grid(row=2, column=0)
        self.exit_btn.grid(row=3, column=0)
        
        
        self.file_ent.grid(row=0, column=1)
        self.dir_ent.grid(row=1, column=1)
        self.pixelsize_ent.grid(row=2, column=1)

        self.start_btn.grid(row=0, column=2)      
        return
    # Read in of the file name    
    def get_file_name(self):
        self.__file_name = file_name = filedialog.askopenfilename()
        head, tail = os.path.split(file_name)
        self.file_ent['fg'] = 'black'
        self.file_name.set(tail)
        self.got_file_name = True
        self.been_analysed = False
        return
    # Setting the dictoniary for results. The dictoniary should be in the same folder as the script   
    def get_dir_name(self):
        self.__dir_name = dir_name = filedialog.askdirectory()
        head, tail = os.path.split(dir_name)
        self.dir_ent['fg'] = 'black'
        self.dir_name.set(tail)
        self.got_dir_name = True
        return
    # Setting of the pixelsize
    def settopixelsize(self):
        self.__pixelsize = self.setpixelsize.get()
        return
        
    # Starting the script   
    def run(self):
        if not self.been_analysed:
            self.been_analysed = False
            if self.got_dir_name and self.got_file_name:
                print("running...") 
                print(self.__pixelsize) 
                analyse(self.__file_name, self.__dir_name,float(self.__pixelsize))
                self.been_analysed = True
            
        return

        
# script entry
# =============================================================================
        
root = tkinter.Tk()
root.title("Microlitter analysis")
app = MyApp(root)
root.mainloop()
        
# =============================================================================
# end of file *gui_fiber_version1.p*
# =============================================================================
